package com.uas.eis.service;

import java.util.List;
import java.util.Map;

public interface MESDataService {

	List<Map<Object,Object>> snStepPass(String accessKey, String requestId, String data);

	List<Map<Object,Object>> snInfo(String accessKey, String requestId, String data);

	List<Map<Object,Object>> makeSnRelation(String accessKey, String requestId, String data);

	List<Map<Object,Object>> MAKEBAD(String accessKey, String requestId, String data);

	List<Map<Object,Object>> makeBadReason(String accessKey, String requestId, String data);

	List<Map<Object,Object>> packageDetail(String accessKey, String requestId, String data);
}